# Overview

The project `Hello365` is a template to demonstrate the use of the 365Connect API. It shows how to access existing fields, persons and machines and how to create new entities. You can use the project to check your 365Connect credentials or to bootstrap your own 365Connect component. For more information about 365Connect, please visit our [developer portal](https://developer.365farmnet.com/).

Hello365 contains:

* a rudimentary frontend project written in Angular 8 and
* a backend project written in Java 11 with Spring Boot 2.

Maven is used as build-management-tool and separates the project into backend and frontend modules.

# Quick start

## Start Hello365

### Preconditions (needed tools on your machine)

* Java 11 or higher (`openjdk` is needed as Oracle has an unsolved issue in current jdk11)
* Maven to build/start the project (including frontend)
* node for frontend development (we recommend at least version 10)

### Build and start

```bash
$ mvn
```

will launch the default goal to build and install the application.

If you want to launch the backend only:

```bash
$ mvn -pl backend spring-boot:run "-Dspring-boot.run.arguments=--api.connect.publicKeyFile=365farmnet_public_key_development.pem,--api.connect.id=5726c2cf-143b-4834-aa54-24a1c1516a48,--api.connect.secret=trsL26xTtFXgPHBJE8n4ZrN6R7fWfLrK,--server.port=3003,--server.servlet.context-path=/hello365"
```

## Display Hello365 within our Devcon-Environment

### Open "Own Integration"

For the Hello365 application to be able to access the 365FarmNet platform, the application must be loaded within the partner iframe. The easiest way to test this is through the devcon environment. We offer a generic partner connection where that can display the Hello365 application by entering the url of your local application:

* Register (or login) yourself at [https://devcon.365farmnet.com/](https://devcon.365farmnet.com/)
* Select "Developer" Section
* Select "Own Integration"

### Change the URL for your integration to localhost:3003

Please use the _Change the URL of your application_ link to change the application url to `http://localhost:3003/hello365/`. The Hello365 application should start in your browser.

**Note:** Make sure to turn off security restrictions of your browser (otherwise you will see only an empty page inside the 365FarmNet platform).

The page looks like this:

![365Hello page](./doc/365HelloPage.png)

Here you can switch between machines, fields and persons. All existing entities of the current account will be displayed. By clicking on the 'new' button you can create new entities.

# Digging into the project

To access 365Connect you need a valid Partner JWT. The Partner JWT can be generated by decoding the Connect JWT (which is passed in the iFrame) and resigning the JWT with the partner's id and secret. The validation of Connect JWT and the generation of the Partner JWT is included in the backend-part of this component.

![365Hello architecture](./doc/Hello365ArchitectureV2.png)

## Entering credentials

To enable the backend service to access the 365Connect interfaces you need to copy

```file
backend/src/main/resources/application.properties-template
```

to

```file
backend/src/main/resources/application.properties
```

and set your credentials in the properties (we recommend to avoid persisting the secret inside your repository, but set it externally):

```properties
api.connect.id=
api.connect.secret=
```

To test the app within our playground at [https://devcon.365farmnet.com](https://devcon.365farmnet.com) you can use our developer-access:

```properties
api.connect.id=5726c2cf-143b-4834-aa54-24a1c1516a48
api.connect.secret=trsL26xTtFXgPHBJE8n4ZrN6R7fWfLrK
```

# References

* [Developer-Portal](https://developer.365farmnet.com/)
* [Developer-Section](https://devcon.365farmnet.com/)
