package com.farmnet365.hello365.service;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import com.farmnet365.hello365.clients.RestClient;
import com.farmnet365.hello365.model.field.Field;
import com.farmnet365.hello365.model.machine.Machine;
import com.farmnet365.hello365.model.machine.MachineResponse;
import com.farmnet365.hello365.model.person.Person;
import com.farmnet365.hello365.model.person.PersonResponse;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import java.util.Arrays;
import java.util.List;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.anyString;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class ConnectServiceTest {

    private static final String TEST_HEADER = "HGHFDZEJJDFJKWOIFMVNGJKDLHFJGDSZFGe673UEH";
    private static final String TEST_TOKEN = "shgdfwkjsdfjkhfg34987z52475dsjkhefg";
    private static final String TEST_API_BASE = "http://localhost:6352";

    @Mock
    private JwtService jwtService;

    @Mock
    private RestClient restClient;

    @InjectMocks
    private ConnectService connectService;

    @Test
    public void testGetFields() {
        var field1 = new Field();
        field1.setName("Krummsee");
        List<Field> testFields = Arrays.asList(field1);

        when(jwtService.generatePartnerJwt(anyString())).thenReturn(new ConnectApiAuthenticationInfo(TEST_TOKEN, TEST_API_BASE));
        when(restClient.getFields(anyString(), anyString())).thenReturn(testFields);
        List<Field> result = connectService.getFields(TEST_HEADER);

        assertNotNull(result);
        assertEquals(1, result.size());
        assertEquals("Krummsee", result.get(0).getName());
    }

    @Test
    public void testGetPersons() {
        var person1 = new Person();
        person1.setName("Hans Bauer");
        PersonResponse personResponse = new PersonResponse(Arrays.asList(person1));

        when(jwtService.generatePartnerJwt(anyString())).thenReturn(new ConnectApiAuthenticationInfo(TEST_TOKEN, TEST_API_BASE));
        when(restClient.getPersons(anyString(), anyString())).thenReturn(personResponse);
        PersonResponse result = connectService.getPersons(TEST_HEADER);

        assertNotNull(result);
        assertNotNull(result.getList());
        assertEquals(1, result.getList().size());
        assertEquals("Hans Bauer", result.getList().get(0).getName());
    }

    @Test
    public void testGetMachines() {
        var machine = new Machine();
        machine.setName("Schwarter");
        MachineResponse machineResponse = new MachineResponse(List.of(machine));

        when(jwtService.generatePartnerJwt(anyString())).thenReturn(new ConnectApiAuthenticationInfo(TEST_TOKEN, TEST_API_BASE));
        when(restClient.getMachines(anyString(), anyString())).thenReturn(machineResponse);
        MachineResponse result = connectService.getMachines(TEST_HEADER);

        assertNotNull(result);
        assertNotNull(result.getList());
        assertEquals(1, result.getList().size());
        assertEquals("Schwarter", result.getList().get(0).getName());
    }

    @Test
    public void testCreateMachines() {
        var machine = new Machine();
        machine.setName("Pflug");

        when(jwtService.generatePartnerJwt(anyString())).thenReturn(new ConnectApiAuthenticationInfo(TEST_TOKEN, TEST_API_BASE));
        when(restClient.postMachine(anyString(), anyString(), any(Machine.class) )).thenReturn(machine);
        Machine result = connectService.createMachine(machine, TEST_HEADER);

        assertNotNull(result);
        assertEquals("Pflug", result.getName());
    }

    @Test
    public void testCreatePerson() {
        var person = new Person();
        person.setName("Doris Lessing");

        when(jwtService.generatePartnerJwt(anyString())).thenReturn(new ConnectApiAuthenticationInfo(TEST_TOKEN, TEST_API_BASE));
        when(restClient.postPerson(anyString(), anyString(), any(Person.class) )).thenReturn(person);
        Person result = connectService.createPerson(person, TEST_HEADER);

        assertNotNull(result);
        assertEquals("Doris Lessing", result.getName());
    }
}
