package com.farmnet365.hello365.service;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.interfaces.DecodedJWT;
import com.farmnet365.hello365.config.ApiProperties;
import org.bouncycastle.util.encoders.DecoderException;
import org.bouncycastle.util.io.pem.PemObject;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import java.io.IOException;
import java.security.PublicKey;

import static junit.framework.TestCase.assertNull;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class SigningAlgorithmServiceTest {

    @Mock
    private ApiProperties properties;

    @InjectMocks
    private SigningAlgorithmService signingAlgorithmService;


    @Test
    public void readValidPemFileTest() throws IOException {
        when(properties.getPublicKeyFile()).thenReturn("test_valid.pem");
        PemObject pem = signingAlgorithmService.readPemFile();
        assertNotNull(pem);
    }

    @Test(expected = DecoderException.class)
    public void readInValidPemFileTest() throws IOException {
        when(properties.getPublicKeyFile()).thenReturn("test_invalid.pem");
        PemObject pem = signingAlgorithmService.readPemFile();
        assertNull(pem);
    }

    @Test
    public void encodePublicKeyTest() {
        when(properties.getPublicKeyFile()).thenReturn("test_valid.pem");
        PublicKey key = signingAlgorithmService.encodePublicKey();
        assertNotNull(key);
    }

    @Test
    public void encodePublicInvalidKeyTest() {
        when(properties.getPublicKeyFile()).thenReturn("test_notAKey.pem");
        PublicKey key = signingAlgorithmService.encodePublicKey();
        assertNull(key);
    }

    @Test
    public void setupTest() {
        when(properties.getPublicKeyFile()).thenReturn("test_valid.pem");
        when(properties.getSecret()).thenReturn("geheim");
        signingAlgorithmService.setup();
        Algorithm alg = signingAlgorithmService.getPartnerTokenAlgorithm();
        assertEquals("HS256", alg.getName());
        assertNotNull(alg);
    }

}
