import {Component, Inject, LOCALE_ID, OnInit} from '@angular/core';
import {HelloBackendService} from './shared/hello-backend.service';
import {environment} from '../environments/environment';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html'
})
export class AppComponent implements OnInit {

  defaultLanguage = 'en';
  additionalLanguages = ['de'];
  initialized = false;

  constructor(private helloBackendService: HelloBackendService, @Inject(LOCALE_ID) private locale: string) {
  }

  ngOnInit(): void {
    this.redirectToLanguage();
  }

  redirectToLanguage() {
    const lang = this.helloBackendService.connectLocale;
    const jwt = this.helloBackendService.connectToken;
    if (lang && jwt && lang !== this.defaultLanguage && this.additionalLanguages.includes(lang) && lang !== this.locale) {
      window.location.href = environment.contextPath + `/${lang}/index.html?jwt=${jwt}`;
   } else {
      this.initialized = true;
    }
  }
}
