import {Component, OnInit} from '@angular/core';
import {HelloBackendService} from '../shared/hello-backend.service';
import {Field} from './model/field';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Component({
  selector: 'app-fields',
  templateUrl: './fields.component.html'
})
export class FieldsComponent implements OnInit {

  displayedColumns: string[] = ['id', 'name', 'farmableAreaInHa'];
  dataSource: Field[] = [];
  hideNewDialog = true;
  loading = false;

  constructor(private helloBackendService: HelloBackendService) {
  }

  ngOnInit() {
    this.loadFields();
  }

  loadFields(): void {
    if (!this.loading) {
      this.loading = true;
      setTimeout(() => this.helloBackendService.getWithAuth('fields').subscribe(
        result => {
          this.dataSource = result;
          this.loading = false;
        },
        error => {
          console.error('Error :: ' + error);
          this.dataSource = null;
          this.loading = false;
        }
      ), 500);
    }
  }

}
