import {Component} from '@angular/core';
import {Machine} from '../model/machine';
import {HelloBackendService} from '../../shared/hello-backend.service';
import {MatDialogRef} from '@angular/material/dialog';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Component({
  selector: 'app-createmachine',
  templateUrl: './createmachine.component.html'
})
export class CreatemachineComponent {

  machine: Machine;
  machineTypesSelection: any;

  constructor(private helloBackendService: HelloBackendService, public dialogRef: MatDialogRef<CreatemachineComponent>) {
    this.init();
  }

  init(): void {
    this.machine = new Machine();
    this.machineTypesSelection = {
      tractor: false,
      tilling: false,
      transport: false,
      sowing: false,
      cultivate: false,
      plantProtecting: false,
      harvesting: false,
      toFertilize: false,
      other: false
    };
  }

  close(): void {
    this.dialogRef.close();
  }

  create(): void {
    this.setMachineTypes();
    this.helloBackendService.postWithAuth('machines', this.machine).subscribe(
      result => {
        console.log('Sending post on machine: ' + JSON.stringify(this.machine));
        this.close();
      },
      error => {
        console.error('Error :: ' + JSON.stringify(error));
        this.close();
      }
    );
  }

  private setMachineTypes(): void {
    this.machine.machineTypes = [];
    Object.keys(this.machineTypesSelection).forEach(key => this.machineTypesSelection[key] ? this.machine.machineTypes.push(key.toUpperCase()) : null);
    console.log('created machine:' + JSON.stringify(this.machine));
  }
}
