import { Component, OnInit } from '@angular/core';
import { Machine } from './model/machine';
import { HelloBackendService } from '../shared/hello-backend.service';
import { CreatemachineComponent } from './createmachine/createmachine.component';
import { MatDialog } from '@angular/material';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Component({
  selector: 'app-machines',
  templateUrl: './machines.component.html'
})
export class MachinesComponent implements OnInit {

  displayedColumns: string[] = ['id', 'name', 'active'];
  dataSource: Machine[] = [];
  loading = false;

  constructor(private helloBackendService: HelloBackendService, private dialog: MatDialog) {
  }

  ngOnInit() {
    this.loadMachines();
  }

  loadMachines(): void {
    if (!this.loading) {
      this.loading = true;
      setTimeout(() => this.helloBackendService.getWithAuth('machines').subscribe(
        result => {
          this.dataSource = result.list;
          this.loading = false;
        },
        error => {
          console.error('Error :: ' + error);
          this.dataSource = null;
          this.loading = false;
        }
      ), 500);
    }
  }

  createMachine(): void {
    const dialogRef = this.dialog.open(CreatemachineComponent);
    dialogRef.afterClosed().subscribe(result => {
      this.loadMachines();
    });
  }
}
