import {Component, EventEmitter, Output} from '@angular/core';
import {Person} from '../model/person';
import {HelloBackendService} from '../../shared/hello-backend.service';

import {Address} from '../model/address';
import {Telephone} from '../model/telephone';
import {Email} from '../model/email';
import {Country} from '../model/country.enum';
import {AddressType} from '../model/address-type.enum';
import {MatDialogRef} from '@angular/material';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Component({
  selector: 'app-createperson',
  templateUrl: './create-person.component.html'
})
export class CreatePersonComponent {

  person: Person;
  countries: string[];
  addressTypes: string[];


  constructor(private helloBackendService: HelloBackendService, public dialogRef: MatDialogRef<CreatePersonComponent>) {
    this.countries = Object.keys(Country).filter(k => typeof (Country as any)[k] === 'number') as any;
    this.addressTypes = Object.keys(AddressType).filter(k => typeof (AddressType as any)[k] === 'number') as any;
    this.init();
  }

  init(): void {
    this.person = new Person();
    this.person.addresses[0] = new Address();
    this.person.telephones[0] = new Telephone();
    this.person.emails[0] = new Email();
  }

  close(): void {
    this.dialogRef.close();
  }

  create(): void {
    this.helloBackendService.postWithAuth('persons', this.person).subscribe(
      result => {
        console.log('Sending post on person: ' + JSON.stringify(this.person));
        this.close();
      },
      error => {
        console.error('Error :: ' + JSON.stringify(error));
        this.close();
      }
    );

  }
}
