import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { JwtHelperService } from '@auth0/angular-jwt';

import { environment } from '../../environments/environment';

//  Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

@Injectable()
export class HelloBackendService {

  connectToken: string;
  connectLocale: string;
  httpHeaders: { headers: HttpHeaders };

  constructor(private http: HttpClient) {
    this.connectToken = this.getConnectJwtToken();
    this.connectLocale = this.getConnectLocale();
    this.httpHeaders = this.getHttpHeaders();
  }

  public getWithAuth(path): Observable<any> {
    const apiUrl = this.buildServiceUrl(path);
    return this.http.get<any>(apiUrl, this.httpHeaders);
  }

  public postWithAuth(path, entity): Observable<any> {
    const apiUrl = this.buildServiceUrl(path);
    return this.http.post<any>(apiUrl, entity, this.httpHeaders);
  }

  private getConnectJwtToken() {
    const jwtParam = window.location.search.match('jwt=([^&?]*)');
    if (jwtParam && jwtParam.length > 1) {
      return jwtParam[1];
    } else {
      console.error('No jwt token found in url parameters.' + window.location);
    }
  }

  private getConnectLocale() {
    const jwtHelper = new JwtHelperService();
    if (this.connectToken) {
      const decoded = jwtHelper.decodeToken(this.connectToken);
      return decoded['fn-ext'].lan;
    }
  }

  private getHttpHeaders() {
    return {
      headers: new HttpHeaders({
        'Content-Type': 'application/json',
        Authorization: this.connectToken
      })
    };
  }

  private buildServiceUrl(path): string {
    return environment.contextPath + `/rest/${path}`;
  }
}
